Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Aggregate

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb

Overview

Represents the aggregation of a set of population of like records by a certain group. For example, a collection of unit counts can be aggregated and grouped by their state.

Instance Attribute Summary collapse

Instance Attribute Details

#count::Integer

Returns Required. Number of records in the group.

Returns:

  • (::Integer)

    Required. Number of records in the group.



206
207
208
209
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 206

class Aggregate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#group::String

Returns Required. Group by which to aggregate.

Returns:

  • (::String)

    Required. Group by which to aggregate.



206
207
208
209
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 206

class Aggregate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end