Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::AppParams

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb

Overview

AppParams contains the parameters for creating an AppHub Application.

Defined Under Namespace

Classes: Scope

Instance Attribute Summary collapse

Instance Attribute Details

#group::String

Returns Grouping used to construct the name of the AppHub Application. Multiple UnitKinds can specify the same group to use the same Application across their respective units. Corresponds to the app_boundary_id in the ADC composite ApplicationTemplate. Defaults to UnitKind.name.

Returns:

  • (::String)

    Grouping used to construct the name of the AppHub Application. Multiple UnitKinds can specify the same group to use the same Application across their respective units. Corresponds to the app_boundary_id in the ADC composite ApplicationTemplate. Defaults to UnitKind.name



962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 962

class AppParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Scope of an application.
  # @!attribute [rw] type
  #   @return [::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::AppParams::Scope::Type]
  #     Required. Scope Type.
  class Scope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Scope Type.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Regional type.
      TYPE_REGIONAL = 1

      # Global type.
      TYPE_GLOBAL = 2

      # Deprecated: Use TYPE_REGIONAL.
      REGIONAL = 1

      # Deprecated: Use TYPE_GLOBAL.
      GLOBAL = 2
    end
  end
end

#scope::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::AppParams::Scope

Returns Corresponds to the scope in the ADC composite ApplicationTemplate. Defaults to TYPE_REGIONAL.

Returns:



962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 962

class AppParams
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Scope of an application.
  # @!attribute [rw] type
  #   @return [::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::AppParams::Scope::Type]
  #     Required. Scope Type.
  class Scope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Scope Type.
    module Type
      # Unspecified type.
      TYPE_UNSPECIFIED = 0

      # Regional type.
      TYPE_REGIONAL = 1

      # Global type.
      TYPE_GLOBAL = 2

      # Deprecated: Use TYPE_REGIONAL.
      REGIONAL = 1

      # Deprecated: Use TYPE_GLOBAL.
      GLOBAL = 2
    end
  end
end