Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::CreateRolloutKindRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::CreateRolloutKindRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_service.rb
Overview
The request structure for the CreateRolloutKind method.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#rollout_kind ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutKind
Required.
-
#rollout_kind_id ⇒ ::String
Required.
-
#validate_only ⇒ ::Boolean
If "validate_only" is set to true, the service will try to validate that this request would succeed, but will not actually make changes.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent of the rollout kind.
260 261 262 263 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_service.rb', line 260 class CreateRolloutKindRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
260 261 262 263 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_service.rb', line 260 class CreateRolloutKindRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rollout_kind ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutKind
Returns Required. The desired state for the rollout kind.
260 261 262 263 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_service.rb', line 260 class CreateRolloutKindRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rollout_kind_id ⇒ ::String
Returns Required. The ID value for the new rollout kind.
260 261 262 263 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_service.rb', line 260 class CreateRolloutKindRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns If "validate_only" is set to true, the service will try to validate that this request would succeed, but will not actually make changes.
260 261 262 263 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_service.rb', line 260 class CreateRolloutKindRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |