Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::DeleteUnitRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::DeleteUnitRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb
Overview
The request structure for the DeleteUnit method.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
The etag known to the client for the expected state of the unit.
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#validate_only ⇒ ::Boolean
If "validate_only" is set to true, the service will try to validate that this request would succeed, but will not actually make changes.
Instance Attribute Details
#etag ⇒ ::String
Returns The etag known to the client for the expected state of the unit. This is used with state-changing methods to prevent accidental overwrites when multiple user agents might be acting in parallel on the same resource.
An etag wildcard provide optimistic concurrency based on the expected
existence of the unit. The Any wildcard (*) requires that the resource
must already exists, and the Not Any wildcard (!*) requires that it must
not.
652 653 654 655 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 652 class DeleteUnitRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the resource within a service.
652 653 654 655 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 652 class DeleteUnitRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
652 653 654 655 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 652 class DeleteUnitRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns If "validate_only" is set to true, the service will try to validate that this request would succeed, but will not actually make changes.
652 653 654 655 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 652 class DeleteUnitRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |