Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::GetUnitOperationRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb

Overview

The request structure for the GetUnitOperation method.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the resource within a service.

Returns:

  • (::String)

    Required. The resource name of the resource within a service.



700
701
702
703
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 700

class GetUnitOperationRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end