Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Rollout

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb

Overview

Represents a single rollout execution and its results

Defined Under Namespace

Modules: RolloutState Classes: AnnotationsEntry, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.

More info: https://kubernetes.io/docs/user-guide/annotations.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.

    More info: https://kubernetes.io/docs/user-guide/annotations



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#control::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutControl

Returns Optional. Requested change to the execution of this rollout. Default RolloutControl.action is ROLLOUT_ACTION_RUN meaning the rollout will be executed to completion while progressing through all natural Rollout States (such as RUNNING -> SUCCEEDED or RUNNING -> FAILED). Requests can only be made when the Rollout is in a non-terminal state.

Returns:

  • (::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutControl)

    Optional. Requested change to the execution of this rollout. Default RolloutControl.action is ROLLOUT_ACTION_RUN meaning the rollout will be executed to completion while progressing through all natural Rollout States (such as RUNNING -> SUCCEEDED or RUNNING -> FAILED). Requests can only be made when the Rollout is in a non-terminal state.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was created.

Returns:



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Optional. Output only. The time when the rollout finished execution (regardless of success, failure, or cancellation). Will be empty if the rollout hasn't finished yet. Once set, the rollout is in terminal state and all the results are final.

Returns:

  • (::Google::Protobuf::Timestamp)

    Optional. Output only. The time when the rollout finished execution (regardless of success, failure, or cancellation). Will be empty if the rollout hasn't finished yet. Once set, the rollout is in terminal state and all the results are final.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#etag::String (readonly)

Returns Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.

Returns:

  • (::String)

    Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#name::String

Returns Identifier. The resource name (full URI of the resource) following the standard naming scheme:

"projects/{project}/locations/{location}/rollout/{rollout_id}".

Returns:

  • (::String)

    Identifier. The resource name (full URI of the resource) following the standard naming scheme:

    "projects/{project}/locations/{location}/rollout/{rollout_id}"



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#parent_rollout::String (readonly)

Returns Optional. Output only. The direct parent rollout that this rollout is stemming from. The resource name (full URI of the resource) following the standard naming scheme:

"projects/{project}/locations/{location}/rollouts/{rollout_id}".

Returns:

  • (::String)

    Optional. Output only. The direct parent rollout that this rollout is stemming from. The resource name (full URI of the resource) following the standard naming scheme:

    "projects/{project}/locations/{location}/rollouts/{rollout_id}"



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#release::String

Returns Optional. Immutable. Name of the Release that gets rolled out to target Units. Required if no other type of release is specified.

Returns:

  • (::String)

    Optional. Immutable. Name of the Release that gets rolled out to target Units. Required if no other type of release is specified.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#rollout_kind::String

Returns Optional. Immutable. Name of the RolloutKind this rollout is stemming from and adhering to.

Returns:

  • (::String)

    Optional. Immutable. Name of the RolloutKind this rollout is stemming from and adhering to.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#rollout_orchestration_strategy::String

Returns Optional. The strategy used for executing this Rollout. This strategy will override whatever strategy is specified in the RolloutType. If not specified on creation, the strategy from RolloutType will be used.

There are two supported values strategies which are used to control

  • "Google.Cloud.Simple.AllAtOnce"
  • "Google.Cloud.Simple.OneLocationAtATime"

A rollout with one of these simple strategies will rollout across all locations defined in the targeted UnitKind's Saas Locations.

Returns:

  • (::String)

    Optional. The strategy used for executing this Rollout. This strategy will override whatever strategy is specified in the RolloutType. If not specified on creation, the strategy from RolloutType will be used.

    There are two supported values strategies which are used to control

    • "Google.Cloud.Simple.AllAtOnce"
    • "Google.Cloud.Simple.OneLocationAtATime"

    A rollout with one of these simple strategies will rollout across all locations defined in the targeted UnitKind's Saas Locations.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#root_rollout::String (readonly)

Returns Optional. Output only. The root rollout that this rollout is stemming from. The resource name (full URI of the resource) following the standard naming scheme:

"projects/{project}/locations/{location}/rollouts/{rollout_id}".

Returns:

  • (::String)

    Optional. Output only. The root rollout that this rollout is stemming from. The resource name (full URI of the resource) following the standard naming scheme:

    "projects/{project}/locations/{location}/rollouts/{rollout_id}"



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Optional. Output only. The time when the rollout started executing. Will be empty if the rollout hasn't started yet.

Returns:

  • (::Google::Protobuf::Timestamp)

    Optional. Output only. The time when the rollout started executing. Will be empty if the rollout hasn't started yet.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#state::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Rollout::RolloutState (readonly)

Returns Output only. Current state of the rollout.

Returns:



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#state_message::String (readonly)

Returns Output only. Human readable message indicating details about the last state transition.

Returns:

  • (::String)

    Output only. Human readable message indicating details about the last state transition.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#state_transition_time::Google::Protobuf::Timestamp (readonly)

Returns Optional. Output only. The time when the rollout transitioned into its current state.

Returns:



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#stats::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutStats (readonly)

Returns Optional. Output only. Details about the progress of the rollout.

Returns:



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#uid::String (readonly)

Returns Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.

Returns:

  • (::String)

    Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#unit_filter::String

Returns Optional. CEL(https://github.com/google/cel-spec) formatted filter string against Unit. The filter will be applied to determine the eligible unit population. This filter can only reduce, but not expand the scope of the rollout. If not provided, the unit_filter from the RolloutType will be used.

Returns:

  • (::String)

    Optional. CEL(https://github.com/google/cel-spec) formatted filter string against Unit. The filter will be applied to determine the eligible unit population. This filter can only reduce, but not expand the scope of the rollout. If not provided, the unit_filter from the RolloutType will be used.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 138

class Rollout
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The current state of the rollout.
  module RolloutState
    # Unspecified state.
    ROLLOUT_STATE_UNSPECIFIED = 0

    # Rollout is in progress.
    ROLLOUT_STATE_RUNNING = 1

    # Rollout has been paused.
    ROLLOUT_STATE_PAUSED = 2

    # Rollout completed successfully.
    ROLLOUT_STATE_SUCCEEDED = 3

    # Rollout has failed.
    ROLLOUT_STATE_FAILED = 4

    # Rollout has been canceled.
    ROLLOUT_STATE_CANCELLED = 5

    # Rollout is waiting for some condition to be met before starting.
    ROLLOUT_STATE_WAITING = 6

    # Rollout is being canceled.
    ROLLOUT_STATE_CANCELLING = 7

    # Rollout is being resumed.
    ROLLOUT_STATE_RESUMING = 8

    # Rollout is being paused.
    ROLLOUT_STATE_PAUSING = 9
  end
end