Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutStats

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb

Overview

RolloutStats contains information about the progress of a rollout.

Instance Attribute Summary collapse

Instance Attribute Details

#estimated_total_unit_count::Integer (readonly)

Returns Optional. Output only. Estimated number of units based. The estimation is computed upon creation of the rollout.

Returns:

  • (::Integer)

    Optional. Output only. Estimated number of units based. The estimation is computed upon creation of the rollout.



349
350
351
352
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 349

class RolloutStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#operations_by_state::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Aggregate> (readonly)

Returns Optional. Output only. Unordered list. A breakdown of the progress of operations triggered by the rollout. Provides a count of Operations by their state. This can be used to determine the number of units which have been updated, or are scheduled to be updated.

There will be at most one entry per group. Possible values for operation groups are:

  • "SCHEDULED"
  • "PENDING"
  • "RUNNING"
  • "SUCCEEDED"
  • "FAILED"
  • "CANCELLED".

Returns:

  • (::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Aggregate>)

    Optional. Output only. Unordered list. A breakdown of the progress of operations triggered by the rollout. Provides a count of Operations by their state. This can be used to determine the number of units which have been updated, or are scheduled to be updated.

    There will be at most one entry per group. Possible values for operation groups are:

    • "SCHEDULED"
    • "PENDING"
    • "RUNNING"
    • "SUCCEEDED"
    • "FAILED"
    • "CANCELLED"


349
350
351
352
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 349

class RolloutStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end