Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Saas

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb

Overview

Saas is a representation of a SaaS service managed by the Producer.

Defined Under Namespace

Modules: State Classes: AnnotationsEntry, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.

More info: https://kubernetes.io/docs/user-guide/annotations.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.

    More info: https://kubernetes.io/docs/user-guide/annotations



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#application_template::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::CompositeRef

Returns Reference to composite ApplicationTemplate. When specified, the template components will be imported into their equivalent UnitKind, Release and Blueprint resources. Deleted references will not delete imported resources. Should only be specified on source regions, and be unspecified on replica regions.

Returns:

  • (::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::CompositeRef)

    Reference to composite ApplicationTemplate. When specified, the template components will be imported into their equivalent UnitKind, Release and Blueprint resources. Deleted references will not delete imported resources. Should only be specified on source regions, and be unspecified on replica regions.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#blueprint_repo::String (readonly)

Returns Output only. Name of repository in Artifact Registry for system-generated Blueprints, eg. Blueprints of imported ApplicationTemplates.

Returns:

  • (::String)

    Output only. Name of repository in Artifact Registry for system-generated Blueprints, eg. Blueprints of imported ApplicationTemplates.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#conditions::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::SaasCondition> (readonly)

Returns Output only. A set of conditions which indicate the various conditions this resource can have.

Returns:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was created.

Returns:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#error::Google::Rpc::Status (readonly)

Returns Output only. If the state is FAILED, the corresponding error code and message. Defaults to code=OK for all other states.

Returns:

  • (::Google::Rpc::Status)

    Output only. If the state is FAILED, the corresponding error code and message. Defaults to code=OK for all other states.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#etag::String (readonly)

Returns Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.

Returns:

  • (::String)

    Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#locations::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Location>

Returns Optional. List of locations that the service is available in. Rollout refers to the list to generate a rollout plan.

Returns:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#name::String

Returns Identifier. The resource name (full URI of the resource) following the standard naming scheme:

"projects/{project}/locations/{location}/saas/{saas}".

Returns:

  • (::String)

    Identifier. The resource name (full URI of the resource) following the standard naming scheme:

    "projects/{project}/locations/{location}/saas/{saas}"



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#state::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Saas::State (readonly)

Returns Output only. State of the Saas. It is always in ACTIVE state if the application_template is empty.

Returns:



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#uid::String (readonly)

Returns Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.

Returns:

  • (::String)

    Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 101

class Saas
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of the Saas.
  module State
    # State type is unspecified.
    STATE_TYPE_UNSPECIFIED = 0

    # The Saas is ready
    STATE_ACTIVE = 1

    # In the process of importing, synchronizing or replicating
    # ApplicationTemplates
    STATE_RUNNING = 2

    # Failure during process of importing, synchronizing or replicating
    # ApplicationTemplate processing
    STATE_FAILED = 3

    # Deprecated: Use STATE_ACTIVE.
    ACTIVE = 1

    # Deprecated: Use STATE_RUNNING.
    RUNNING = 2

    # Deprecated: Use STATE_FAILED.
    FAILED = 3
  end
end