Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::SaasCondition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb

Overview

SaasCondition describes the status of a Saas.

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Instance Attribute Details

#last_transition_time::Google::Protobuf::Timestamp

Returns Required. Last time the condition transited from one status to another.

Returns:



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 235

class SaasCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is ready.
    TYPE_READY = 1

    # Condition type is synchronized.
    TYPE_SYNCHRONIZED = 2
  end
end

#message::String

Returns Required. Human readable message indicating details about the last transition.

Returns:

  • (::String)

    Required. Human readable message indicating details about the last transition.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 235

class SaasCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is ready.
    TYPE_READY = 1

    # Condition type is synchronized.
    TYPE_SYNCHRONIZED = 2
  end
end

#reason::String

Returns Required. Brief reason for the condition's last transition.

Returns:

  • (::String)

    Required. Brief reason for the condition's last transition.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 235

class SaasCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is ready.
    TYPE_READY = 1

    # Condition type is synchronized.
    TYPE_SYNCHRONIZED = 2
  end
end

#status::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::SaasCondition::Status

Returns Required. Status of the condition.

Returns:



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 235

class SaasCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is ready.
    TYPE_READY = 1

    # Condition type is synchronized.
    TYPE_SYNCHRONIZED = 2
  end
end

#type::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::SaasCondition::Type

Returns Required. Type of the condition.



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 235

class SaasCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is ready.
    TYPE_READY = 1

    # Condition type is synchronized.
    TYPE_SYNCHRONIZED = 2
  end
end