Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::ToMapping
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::ToMapping
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb
Overview
Input variables whose values will be passed on to dependencies
Instance Attribute Summary collapse
-
#dependency ⇒ ::String
Required.
-
#ignore_for_lookup ⇒ ::Boolean
Optional.
-
#input_variable ⇒ ::String
Required.
Instance Attribute Details
#dependency ⇒ ::String
Returns Required. Alias of the dependency that the inputVariable will pass its value to.
818 819 820 821 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 818 class ToMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ignore_for_lookup ⇒ ::Boolean
Returns Optional. Tells App Lifecycle Manager if this mapping should be used during lookup or not.
818 819 820 821 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 818 class ToMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#input_variable ⇒ ::String
Returns Required. Name of the inputVariable on the dependency.
818 819 820 821 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 818 class ToMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |