Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb

Overview

UnitOperation encapsulates the intent of changing/interacting with the service component represented by the specific Unit. Multiple UnitOperations can be created (requested) and scheduled in the future, however only one will be allowed to execute at a time (that can change in the future for non-mutating operations).

UnitOperations allow different actors interacting with the same unit to focus only on the change they have requested.

This is a base object that contains the common fields in all unit operations. Next: 19

Defined Under Namespace

Modules: UnitOperationState Classes: AnnotationsEntry, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.

More info: https://kubernetes.io/docs/user-guide/annotations.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.

    More info: https://kubernetes.io/docs/user-guide/annotations



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#cancel::Boolean

Returns Optional. When true, attempt to cancel the operation. Cancellation may fail if the operation is already executing. (Optional).

Returns:

  • (::Boolean)

    Optional. When true, attempt to cancel the operation. Cancellation may fail if the operation is already executing. (Optional)



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#conditions::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition> (readonly)

Returns Optional. Output only. A set of conditions which indicate the various conditions this resource can have.

Returns:



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was created.

Returns:



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#deprovision::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Deprovision

Returns Note: The following fields are mutually exclusive: deprovision, provision, upgrade. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#engine_state::String (readonly)

Returns Optional. Output only. The engine state for on-going deployment engine operation(s). This field is opaque for external usage.

Returns:

  • (::String)

    Optional. Output only. The engine state for on-going deployment engine operation(s). This field is opaque for external usage.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#error_category::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationErrorCategory (readonly)

Returns Optional. Output only. UnitOperationErrorCategory describe the error category.

Returns:



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#etag::String (readonly)

Returns Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.

Returns:

  • (::String)

    Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#name::String

Returns Identifier. The resource name (full URI of the resource) following the standard naming scheme:

"projects/{project}/locations/{location}/unitOperations/{unitOperation}".

Returns:

  • (::String)

    Identifier. The resource name (full URI of the resource) following the standard naming scheme:

    "projects/{project}/locations/{location}/unitOperations/{unitOperation}"



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#parent_unit_operation::String

Returns Optional. Reference to parent resource: UnitOperation. If an operation needs to create other operations as part of its workflow, each of the child operations should have this field set to the parent. This can be used for tracing. (Optional).

Returns:

  • (::String)

    Optional. Reference to parent resource: UnitOperation. If an operation needs to create other operations as part of its workflow, each of the child operations should have this field set to the parent. This can be used for tracing. (Optional)



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#provision::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Provision

Returns Note: The following fields are mutually exclusive: provision, upgrade, deprovision. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#rollout::String

Returns Optional. Specifies which rollout created this Unit Operation. This cannot be modified and is used for filtering purposes only. If a dependent unit and unit operation are created as part of another unit operation, they will use the same rolloutId.

Returns:

  • (::String)

    Optional. Specifies which rollout created this Unit Operation. This cannot be modified and is used for filtering purposes only. If a dependent unit and unit operation are created as part of another unit operation, they will use the same rolloutId.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#schedule::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Schedule

Returns Optional. When to schedule this operation.

Returns:



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#state::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperation::UnitOperationState (readonly)

Returns Optional. Output only. UnitOperationState describes the current state of the unit operation.

Returns:



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#uid::String (readonly)

Returns Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.

Returns:

  • (::String)

    Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#unit::String

Returns Required. Immutable. The Unit a given UnitOperation will act upon.

Returns:

  • (::String)

    Required. Immutable. The Unit a given UnitOperation will act upon.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end

#upgrade::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Upgrade

Returns Note: The following fields are mutually exclusive: upgrade, provision, deprovision. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 582

class UnitOperation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # UnitOperationState describes the current state of the unit operation.
  module UnitOperationState
    UNIT_OPERATION_STATE_UNKNOWN = 0

    # Unit operation is accepted but not ready to run.
    UNIT_OPERATION_STATE_PENDING = 1

    # Unit operation is accepted and scheduled.
    UNIT_OPERATION_STATE_SCHEDULED = 2

    # Unit operation is running.
    UNIT_OPERATION_STATE_RUNNING = 4

    # Unit operation has completed successfully.
    UNIT_OPERATION_STATE_SUCCEEDED = 5

    # Unit operation has failed.
    UNIT_OPERATION_STATE_FAILED = 6

    # Unit operation was cancelled.
    UNIT_OPERATION_STATE_CANCELLED = 7
  end
end