Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb

Overview

UnitOperationCondition describes the status of an Unit Operation. UnitOperationCondition is individual components that contribute to an overall state.

Defined Under Namespace

Modules: Status, Type

Instance Attribute Summary collapse

Instance Attribute Details

#last_transition_time::Google::Protobuf::Timestamp

Returns Required. Last time the condition transited from one status to another.

Returns:



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 167

class UnitOperationCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is scheduled.
    TYPE_SCHEDULED = 2

    # Condition type is running.
    TYPE_RUNNING = 3

    # Condition type is succeeded.
    TYPE_SUCCEEDED = 4

    # Condition type is cancelled.
    TYPE_CANCELLED = 5

    # Indicates if AppHub app has been created.
    TYPE_APP_CREATED = 6

    # Indicates if services and workloads have been registered with AppHub.
    TYPE_APP_COMPONENTS_REGISTERED = 7

    # Indicates if the UnitOperation's core workload execution completed
    # successfully.
    # The workload is the core execution operation performed for a
    # UnitOperation (e.g., provisioning, updating, or deprovisioning
    # resources) excluding post-operation checks.
    TYPE_WORKLOAD_SUCCEEDED = 8
  end
end

#message::String

Returns Required. Human readable message indicating details about the last transition.

Returns:

  • (::String)

    Required. Human readable message indicating details about the last transition.



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 167

class UnitOperationCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is scheduled.
    TYPE_SCHEDULED = 2

    # Condition type is running.
    TYPE_RUNNING = 3

    # Condition type is succeeded.
    TYPE_SUCCEEDED = 4

    # Condition type is cancelled.
    TYPE_CANCELLED = 5

    # Indicates if AppHub app has been created.
    TYPE_APP_CREATED = 6

    # Indicates if services and workloads have been registered with AppHub.
    TYPE_APP_COMPONENTS_REGISTERED = 7

    # Indicates if the UnitOperation's core workload execution completed
    # successfully.
    # The workload is the core execution operation performed for a
    # UnitOperation (e.g., provisioning, updating, or deprovisioning
    # resources) excluding post-operation checks.
    TYPE_WORKLOAD_SUCCEEDED = 8
  end
end

#reason::String

Returns Required. Brief reason for the condition's last transition.

Returns:

  • (::String)

    Required. Brief reason for the condition's last transition.



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 167

class UnitOperationCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is scheduled.
    TYPE_SCHEDULED = 2

    # Condition type is running.
    TYPE_RUNNING = 3

    # Condition type is succeeded.
    TYPE_SUCCEEDED = 4

    # Condition type is cancelled.
    TYPE_CANCELLED = 5

    # Indicates if AppHub app has been created.
    TYPE_APP_CREATED = 6

    # Indicates if services and workloads have been registered with AppHub.
    TYPE_APP_COMPONENTS_REGISTERED = 7

    # Indicates if the UnitOperation's core workload execution completed
    # successfully.
    # The workload is the core execution operation performed for a
    # UnitOperation (e.g., provisioning, updating, or deprovisioning
    # resources) excluding post-operation checks.
    TYPE_WORKLOAD_SUCCEEDED = 8
  end
end

#status::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition::Status

Returns Required. Status of the condition.



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 167

class UnitOperationCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is scheduled.
    TYPE_SCHEDULED = 2

    # Condition type is running.
    TYPE_RUNNING = 3

    # Condition type is succeeded.
    TYPE_SUCCEEDED = 4

    # Condition type is cancelled.
    TYPE_CANCELLED = 5

    # Indicates if AppHub app has been created.
    TYPE_APP_CREATED = 6

    # Indicates if services and workloads have been registered with AppHub.
    TYPE_APP_COMPONENTS_REGISTERED = 7

    # Indicates if the UnitOperation's core workload execution completed
    # successfully.
    # The workload is the core execution operation performed for a
    # UnitOperation (e.g., provisioning, updating, or deprovisioning
    # resources) excluding post-operation checks.
    TYPE_WORKLOAD_SUCCEEDED = 8
  end
end

#type::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition::Type

Returns Required. Type of the condition.



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 167

class UnitOperationCondition
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of condition statuses.
  module Status
    # Condition status is unspecified.
    STATUS_UNSPECIFIED = 0

    # Condition is unknown.
    STATUS_UNKNOWN = 1

    # Condition is true.
    STATUS_TRUE = 2

    # Condition is false.
    STATUS_FALSE = 3
  end

  # Enumeration of condition types.
  module Type
    # Condition type is unspecified.
    TYPE_UNSPECIFIED = 0

    # Condition type is scheduled.
    TYPE_SCHEDULED = 2

    # Condition type is running.
    TYPE_RUNNING = 3

    # Condition type is succeeded.
    TYPE_SUCCEEDED = 4

    # Condition type is cancelled.
    TYPE_CANCELLED = 5

    # Indicates if AppHub app has been created.
    TYPE_APP_CREATED = 6

    # Indicates if services and workloads have been registered with AppHub.
    TYPE_APP_COMPONENTS_REGISTERED = 7

    # Indicates if the UnitOperation's core workload execution completed
    # successfully.
    # The workload is the core execution operation performed for a
    # UnitOperation (e.g., provisioning, updating, or deprovisioning
    # resources) excluding post-operation checks.
    TYPE_WORKLOAD_SUCCEEDED = 8
  end
end