Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UpdateUnitOperationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UpdateUnitOperationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb
Overview
The request structure for the UpdateUnitOperation method.
Instance Attribute Summary collapse
-
#request_id ⇒ ::String
An optional request ID to identify requests.
-
#unit_operation ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperation
Required.
-
#update_mask ⇒ ::Google::Protobuf::FieldMask
Field mask is used to specify the fields to be overwritten in the UnitOperation resource by the update.
-
#validate_only ⇒ ::Boolean
If "validate_only" is set to true, the service will try to validate that this request would succeed, but will not actually make changes.
Instance Attribute Details
#request_id ⇒ ::String
Returns An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
772 773 774 775 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 772 class UpdateUnitOperationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unit_operation ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperation
Returns Required. The desired state for the unit operation.
772 773 774 775 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 772 class UpdateUnitOperationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_mask ⇒ ::Google::Protobuf::FieldMask
Returns Field mask is used to specify the fields to be overwritten in the UnitOperation resource by the update.
The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask.
If the user does not provide a mask then all fields in the UnitOperation will be overwritten.
772 773 774 775 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 772 class UpdateUnitOperationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns If "validate_only" is set to true, the service will try to validate that this request would succeed, but will not actually make changes.
772 773 774 775 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_service.rb', line 772 class UpdateUnitOperationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |