Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Upgrade
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Upgrade
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb
Overview
Upgrade is the unit operation that upgrades a provisioned unit, which may also include the underlying resources represented by a Unit. Can only execute if the Unit is currently provisioned.
Instance Attribute Summary collapse
-
#input_variables ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable>
Optional.
-
#release ⇒ ::String
Optional.
Instance Attribute Details
#input_variables ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable>
Returns Optional. Set of input variables. Maximum 100. (optional).
659 660 661 662 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 659 class Upgrade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#release ⇒ ::String
Returns Optional. Reference to the Release object to use for the Unit. (optional).
659 660 661 662 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 659 class Upgrade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |