Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Aggregate
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Aggregate
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb
Overview
Represents the aggregation of a set of population of like records by a certain group. For example, a collection of unit counts can be aggregated and grouped by their state.
Instance Attribute Summary collapse
-
#count ⇒ ::Integer
Required.
-
#group ⇒ ::String
Required.