Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Blueprint
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Blueprint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb
Overview
Blueprints are OCI Images that contain all of the artifacts needed to provision a unit. Metadata such as, type of the engine used to actuate the blueprint (e.g. terraform, helm etc) and version will come from the image manifest. If the hostname is omitted, it will be assumed to be the regional path to Artifact Registry (eg. us-east1-docker.pkg.dev).
Instance Attribute Summary collapse
-
#engine ⇒ ::String
readonly
Output only.
-
#package ⇒ ::String
Optional.
-
#version ⇒ ::String
readonly
Output only.
Instance Attribute Details
#engine ⇒ ::String (readonly)
Returns Output only. Type of the engine used to actuate the blueprint. e.g. terraform, helm etc.
41 42 43 44 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 41 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#package ⇒ ::String
Returns Optional. Immutable. URI to a blueprint used by the Unit (required unless unitKind or release is set).
41 42 43 44 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 41 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#version ⇒ ::String (readonly)
Returns Output only. Version metadata if present on the blueprint.
41 42 43 44 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 41 class Blueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |