Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::ComponentRef
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::ComponentRef
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb
Overview
ComponentRef represents a reference to a component resource. Next ID: 4
Instance Attribute Summary collapse
-
#component ⇒ ::String
Name of the component in composite.Components.
-
#composite_ref ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::CompositeRef
Reference to the Composite ApplicationTemplate.
-
#revision ⇒ ::String
Revision of the component.
Instance Attribute Details
#component ⇒ ::String
Returns Name of the component in composite.Components.
945 946 947 948 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 945 class ComponentRef include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#composite_ref ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::CompositeRef
Returns Reference to the Composite ApplicationTemplate.
945 946 947 948 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 945 class ComponentRef include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#revision ⇒ ::String
Returns Revision of the component. If the component does not have a revision, this field will be explicitly set to the revision of the composite ApplicationTemplate.
945 946 947 948 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 945 class ComponentRef include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |