Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Provision
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Provision
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb
Overview
Provision is the unit operation that provision the underlying resources represented by a Unit. Can only execute if the Unit is not currently provisioned.
Instance Attribute Summary collapse
-
#input_variables ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable>
Optional.
-
#release ⇒ ::String
Optional.
Instance Attribute Details
#input_variables ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable>
Returns Optional. Set of input variables. Maximum 100. (optional).
637 638 639 640 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 637 class Provision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#release ⇒ ::String
Returns Optional. Reference to the Release object to use for the Unit. (optional).
637 638 639 640 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 637 class Provision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |