Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Release
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Release
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb
Overview
A new version to be propagated and deployed to units. This includes pointers to packaged blueprints for actuation (e.g Helm or Terraform configuration packages) via artifact registry.
Defined Under Namespace
Classes: AnnotationsEntry, LabelsEntry, ReleaseRequirements
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#blueprint ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Blueprint
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#etag ⇒ ::String
readonly
Output only.
-
#input_variable_defaults ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable>
Optional.
-
#input_variables ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable>
readonly
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#output_variables ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable>
readonly
Optional.
-
#release_requirements ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Release::ReleaseRequirements
Optional.
-
#uid ⇒ ::String
readonly
Output only.
-
#unit_kind ⇒ ::String
Required.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.
More info: https://kubernetes.io/docs/user-guide/annotations.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#blueprint ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Blueprint
Returns Optional. Blueprints are OCI Images that contain all of the artifacts needed to provision a unit.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was created.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#etag ⇒ ::String (readonly)
Returns Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#input_variable_defaults ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable>
Returns Optional. Mapping of input variables to default values. Maximum 100.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#input_variables ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable> (readonly)
Returns Optional. Output only. List of input variables declared on the blueprint and can be present with their values on the unit spec.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The resource name (full URI of the resource) following the standard naming scheme:
"projects/{project}/locations/{location}/releases/{release}".
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#output_variables ⇒ ::Array<::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitVariable> (readonly)
Returns Optional. Output only. List of output variables declared on the blueprint and can be present with their values on the unit status.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#release_requirements ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::Release::ReleaseRequirements
Returns Optional. Set of requirements to be fulfilled on the Unit when using this Release.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uid ⇒ ::String (readonly)
Returns Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#unit_kind ⇒ ::String
Returns Required. Immutable. Reference to the UnitKind this Release corresponds to (required and immutable once created).
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.
738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 738 class Release include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Set of requirements to be fulfilled on the Unit when using this Release. # @!attribute [rw] upgradeable_from_releases # @return [::Array<::String>] # Optional. A list of releases from which a unit can be upgraded to this # one (optional). If left empty no constraints will be applied. When # provided, unit upgrade requests to this release will check and enforce # this constraint. class ReleaseRequirements include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |