Module: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutAction
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb
Overview
RolloutAction indicates the action to be performed on the Rollout.
Constant Summary collapse
- ROLLOUT_ACTION_UNSPECIFIED =
Unspecified action, will be treated as RUN by default.
0- ROLLOUT_ACTION_RUN =
Run the Rollout until it naturally reaches a terminal state. A rollout requested to run will progress through all natural Rollout States (such as RUNNING -> SUCCEEDED or RUNNING -> FAILED). If retriable errors are encountered during the rollout, the rollout will paused by default and can be resumed by re-requesting this RUN action.
1- ROLLOUT_ACTION_PAUSE =
Pause the Rollout until it is resumed (i.e. RUN is requested).
2- ROLLOUT_ACTION_CANCEL =
Cancel the Rollout permanently.
3