Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutControl
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutControl
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb
Overview
RolloutControl provides a way to request a change to the execution of a Rollout by pausing or canceling it.
Defined Under Namespace
Classes: RunRolloutActionParams
Instance Attribute Summary collapse
-
#action ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutAction
Required.
-
#run_params ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutControl::RunRolloutActionParams
Optional.
Instance Attribute Details
#action ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutAction
Returns Required. Action to be performed on the Rollout. The default behavior is to run the rollout until it naturally reaches a terminal state.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 349 class RolloutControl include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters for the RUN action controlling the behavior of the rollout # when it is resumed from a PAUSED state. # @!attribute [rw] retry_failed_operations # @return [::Boolean] # Required. If true, the rollout will retry failed operations when resumed. # This is applicable only the current state of the Rollout is PAUSED and # the requested action is RUN. class RunRolloutActionParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#run_params ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutControl::RunRolloutActionParams
Returns Optional. Parameters for the RUN action. It is an error to specify this if the RolloutAction is not set to RUN. By default, the rollout will retry failed operations when resumed.
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 349 class RolloutControl include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters for the RUN action controlling the behavior of the rollout # when it is resumed from a PAUSED state. # @!attribute [rw] retry_failed_operations # @return [::Boolean] # Required. If true, the rollout will retry failed operations when resumed. # This is applicable only the current state of the Rollout is PAUSED and # the requested action is RUN. class RunRolloutActionParams include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |