Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutKind
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutKind
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb
Overview
An object that describes various settings of Rollout execution. Includes built-in policies across GCP and GDC, and customizable policies.
Defined Under Namespace
Modules: UpdateUnitKindStrategy Classes: AnnotationsEntry, LabelsEntry
Instance Attribute Summary collapse
-
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#error_budget ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::ErrorBudget
Optional.
-
#etag ⇒ ::String
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
Identifier.
-
#rollout_orchestration_strategy ⇒ ::String
Optional.
-
#uid ⇒ ::String
readonly
Output only.
-
#unit_filter ⇒ ::String
Optional.
-
#unit_kind ⇒ ::String
Required.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#update_unit_kind_strategy ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutKind::UpdateUnitKindStrategy
Optional.
Instance Attribute Details
#annotations ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects.
More info: https://kubernetes.io/docs/user-guide/annotations.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was created.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#error_budget ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::ErrorBudget
Returns Optional. The configuration for error budget. If the number of failed units exceeds max(allowed_count, allowed_ratio * total_units), the rollout will be paused. If not set, all units will be attempted to be updated regardless of the number of failures encountered.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#etag ⇒ ::String (readonly)
Returns Output only. An opaque value that uniquely identifies a version or generation of a resource. It can be used to confirm that the client and server agree on the ordering of a resource being written.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. The labels on the resource, which can be used for categorization. similar to Kubernetes resource labels.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#name ⇒ ::String
Returns Identifier. The resource name (full URI of the resource) following the standard naming scheme:
"projects/{project}/locations/{location}/rolloutKinds/{rollout_kind_id}".
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#rollout_orchestration_strategy ⇒ ::String
Returns Optional. The strategy used for executing a Rollout. This is a required field.
There are two supported values strategies which are used to control
- "Google.Cloud.Simple.AllAtOnce"
- "Google.Cloud.Simple.OneLocationAtATime"
A rollout with one of these simple strategies will rollout across all locations defined in the associated UnitKind's Saas Locations.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#uid ⇒ ::String (readonly)
Returns Output only. The unique identifier of the resource. UID is unique in the time and space for this resource within the scope of the service. It is typically generated by the server on successful creation of a resource and must not be changed. UID is used to uniquely identify resources with resource name reuses. This should be a UUID4.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#unit_filter ⇒ ::String
Returns Optional. CEL(https://github.com/google/cel-spec) formatted filter string against Unit. The filter will be applied to determine the eligible unit population. This filter can only reduce, but not expand the scope of the rollout.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#unit_kind ⇒ ::String
Returns Required. Immutable. UnitKind that this rollout kind corresponds to. Rollouts stemming from this rollout kind will target the units of this unit kind. In other words, this defines the population of target units to be upgraded by rollouts.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp when the resource was last updated. Any change to the resource made by users must refresh this value. Changes to a resource made by the service should refresh this value.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |
#update_unit_kind_strategy ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::RolloutKind::UpdateUnitKindStrategy
Returns Optional. The config for updating the unit kind. By default, the unit kind will be updated on the rollout start.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/rollouts_resources.rb', line 267 class RolloutKind include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AnnotationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end module UpdateUnitKindStrategy # Strategy unspecified. UPDATE_UNIT_KIND_STRATEGY_UNSPECIFIED = 0 # Update the unit kind strategy on the rollout start. UPDATE_UNIT_KIND_STRATEGY_ON_START = 1 # Never update the unit kind. UPDATE_UNIT_KIND_STRATEGY_NEVER = 2 end end |