Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitCondition
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitCondition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb
Overview
UnitCondition describes the status of an Unit. UnitCondition is individual components that contribute to an overall state.
Defined Under Namespace
Instance Attribute Summary collapse
-
#last_transition_time ⇒ ::Google::Protobuf::Timestamp
Required.
-
#message ⇒ ::String
Required.
-
#reason ⇒ ::String
Required.
-
#status ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitCondition::Status
Required.
-
#type ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitCondition::Type
Required.
Instance Attribute Details
#last_transition_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. Last time the condition transited from one status to another.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 95 class UnitCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is ready. TYPE_READY = 1 # Condition type is updating. TYPE_UPDATING = 2 # Condition type is provisioned. TYPE_PROVISIONED = 3 # Condition type is operationError. # True when the last unit operation fails with a non-ignorable error. TYPE_OPERATION_ERROR = 4 end end |
#message ⇒ ::String
Returns Required. Human readable message indicating details about the last transition.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 95 class UnitCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is ready. TYPE_READY = 1 # Condition type is updating. TYPE_UPDATING = 2 # Condition type is provisioned. TYPE_PROVISIONED = 3 # Condition type is operationError. # True when the last unit operation fails with a non-ignorable error. TYPE_OPERATION_ERROR = 4 end end |
#reason ⇒ ::String
Returns Required. Brief reason for the condition's last transition.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 95 class UnitCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is ready. TYPE_READY = 1 # Condition type is updating. TYPE_UPDATING = 2 # Condition type is provisioned. TYPE_PROVISIONED = 3 # Condition type is operationError. # True when the last unit operation fails with a non-ignorable error. TYPE_OPERATION_ERROR = 4 end end |
#status ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitCondition::Status
Returns Required. Status of the condition.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 95 class UnitCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is ready. TYPE_READY = 1 # Condition type is updating. TYPE_UPDATING = 2 # Condition type is provisioned. TYPE_PROVISIONED = 3 # Condition type is operationError. # True when the last unit operation fails with a non-ignorable error. TYPE_OPERATION_ERROR = 4 end end |
#type ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitCondition::Type
Returns Required. Type of the condition.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 95 class UnitCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is ready. TYPE_READY = 1 # Condition type is updating. TYPE_UPDATING = 2 # Condition type is provisioned. TYPE_PROVISIONED = 3 # Condition type is operationError. # True when the last unit operation fails with a non-ignorable error. TYPE_OPERATION_ERROR = 4 end end |