Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb
Overview
UnitOperationCondition describes the status of an Unit Operation. UnitOperationCondition is individual components that contribute to an overall state.
Defined Under Namespace
Instance Attribute Summary collapse
-
#last_transition_time ⇒ ::Google::Protobuf::Timestamp
Required.
-
#message ⇒ ::String
Required.
-
#reason ⇒ ::String
Required.
-
#status ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition::Status
Required.
-
#type ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition::Type
Required.
Instance Attribute Details
#last_transition_time ⇒ ::Google::Protobuf::Timestamp
Returns Required. Last time the condition transited from one status to another.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 153 class UnitOperationCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is scheduled. TYPE_SCHEDULED = 2 # Condition type is running. TYPE_RUNNING = 3 # Condition type is succeeded. TYPE_SUCCEEDED = 4 # Condition type is cancelled. TYPE_CANCELLED = 5 # Indicates if AppHub app has been created. TYPE_APP_CREATED = 6 # Indicates if services and workloads have been registered with AppHub. TYPE_APP_COMPONENTS_REGISTERED = 7 end end |
#message ⇒ ::String
Returns Required. Human readable message indicating details about the last transition.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 153 class UnitOperationCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is scheduled. TYPE_SCHEDULED = 2 # Condition type is running. TYPE_RUNNING = 3 # Condition type is succeeded. TYPE_SUCCEEDED = 4 # Condition type is cancelled. TYPE_CANCELLED = 5 # Indicates if AppHub app has been created. TYPE_APP_CREATED = 6 # Indicates if services and workloads have been registered with AppHub. TYPE_APP_COMPONENTS_REGISTERED = 7 end end |
#reason ⇒ ::String
Returns Required. Brief reason for the condition's last transition.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 153 class UnitOperationCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is scheduled. TYPE_SCHEDULED = 2 # Condition type is running. TYPE_RUNNING = 3 # Condition type is succeeded. TYPE_SUCCEEDED = 4 # Condition type is cancelled. TYPE_CANCELLED = 5 # Indicates if AppHub app has been created. TYPE_APP_CREATED = 6 # Indicates if services and workloads have been registered with AppHub. TYPE_APP_COMPONENTS_REGISTERED = 7 end end |
#status ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition::Status
Returns Required. Status of the condition.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 153 class UnitOperationCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is scheduled. TYPE_SCHEDULED = 2 # Condition type is running. TYPE_RUNNING = 3 # Condition type is succeeded. TYPE_SUCCEEDED = 4 # Condition type is cancelled. TYPE_CANCELLED = 5 # Indicates if AppHub app has been created. TYPE_APP_CREATED = 6 # Indicates if services and workloads have been registered with AppHub. TYPE_APP_COMPONENTS_REGISTERED = 7 end end |
#type ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::UnitOperationCondition::Type
Returns Required. Type of the condition.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/common.rb', line 153 class UnitOperationCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of condition statuses. module Status # Condition status is unspecified. STATUS_UNSPECIFIED = 0 # Condition is unknown. STATUS_UNKNOWN = 1 # Condition is true. STATUS_TRUE = 2 # Condition is false. STATUS_FALSE = 3 end # Enumeration of condition types. module Type # Condition type is unspecified. TYPE_UNSPECIFIED = 0 # Condition type is scheduled. TYPE_SCHEDULED = 2 # Condition type is running. TYPE_RUNNING = 3 # Condition type is succeeded. TYPE_SUCCEEDED = 4 # Condition type is cancelled. TYPE_CANCELLED = 5 # Indicates if AppHub app has been created. TYPE_APP_CREATED = 6 # Indicates if services and workloads have been registered with AppHub. TYPE_APP_COMPONENTS_REGISTERED = 7 end end |