Class: Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::VariableMapping
- Inherits:
-
Object
- Object
- Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::VariableMapping
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb
Overview
Mapping of input variables to their respective output variable for depedenencies
Instance Attribute Summary collapse
-
#from ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::FromMapping
Optional.
-
#to ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::ToMapping
Optional.
-
#variable ⇒ ::String
Required.
Instance Attribute Details
#from ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::FromMapping
Returns Optional. Output variables which will get their values from dependencies
Note: The following fields are mutually exclusive: from, to. If a field in that set is populated, all other fields in the set will automatically be cleared.
788 789 790 791 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 788 class VariableMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#to ⇒ ::Google::Cloud::SaasPlatform::SaasServiceMgmt::V1beta1::ToMapping
Returns Optional. Input variables whose values will be passed on to dependencies.
Note: The following fields are mutually exclusive: to, from. If a field in that set is populated, all other fields in the set will automatically be cleared.
788 789 790 791 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 788 class VariableMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#variable ⇒ ::String
Returns Required. name of the variable.
788 789 790 791 |
# File 'proto_docs/google/cloud/saasplatform/saasservicemgmt/v1beta1/deployments_resources.rb', line 788 class VariableMapping include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |